#!/bin/bash
# Author : Guth (guth@ploposor.com)
# Source : http://www.ijs.si/software/amavisd/amavisd-new.tar.gz

# program name/version
softversion='2.5.3'
softname='amavisd-new'

# architecture/package version
arch='noarch'
cpu='i686'
packageversion='52.2'

# number of parallel tasks of make
ntasks='-j2'

# parameters needed for the build process
buildir=$(pwd)
package="$softname-$softversion-$arch-$packageversion"

# prepare the build result directory
dest="$buildir/$package"
rm -rf $dest
rm -f $package.*
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/src/$softname-$softversion

# make a slack-desc file
cat <<EOF > $dest/install/slack-desc
       |-----handy-ruler------------------------------------------------------|
amavisd-new: An interface between mailer (MTA) and content checkers
amavisd-new:
amavisd-new: Amavisd-new is an interface between mailer and content checkers
amavisd-new: (virus scanners, and/or SpamAssassin). It is written in Perl.
amavisd-new: It talks to MTA via (E)SMTP or LMTP, or by using helper programs.
amavisd-new: 
amavisd-new: 
amavisd-new: 
amavisd-new: 
amavisd-new: 
amavisd-new: 
EOF

# extract sources
echo -n "extracting ..."
srcdir="$softname-$softversion"
cd $buildir
rm -rf $srcdir
tar zxf $srcdir.tar.gz
cd $srcdir

# set correct permissions
chown -R root.root .
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
echo " done"

# configure package for compilation

echo -n "configuring ..."

mkdir -p $dest/usr/doc/$softname-$softversion

# install package to the target directory
mkdir -p $dest/usr/sbin
cp amavisd amavisd-release amavisd-nanny $dest/usr/sbin/
chown root $dest/usr/sbin/amavisd
chmod 755  $dest/usr/sbin/amavisd

mkdir -p $dest/etc/amavis
cp amavisd.conf $dest/etc/amavis/amavisd.conf.new

sed -i "s/.*\(\$daemon_user *= *'\).*\(' *\;.*\)/\1amavis\2/g" $dest/etc/amavis/amavisd.conf.new
sed -i "s/.*\(\$daemon_group *= *'\).*\(' *\;.*\)/\1amavis\2/g" $dest/etc/amavis/amavisd.conf.new
sed -i "s/.*\(\$MYHOME *= *'\).*\(' *\;.*\)/\1\/var\/lib\/amavis\2/g" $dest/etc/amavis/amavisd.conf.new
sed -i "s/.*\(\$QUARANTINEDIR *= *' *\).*\('\;.*\)/\1\/var\/lib\/amavis\/quarantine\2/g" $dest/etc/amavis/amavisd.conf.new
sed -i "s/.*\(\$MYHOME *= *'\).*\(' *\;.*\)/\1\/var\/lib\/amavis\2/g" $dest/etc/amavis/amavisd.conf.new
sed -i 's/\(.*\)\/var\/amavis\(.*\)/\1\/var\/lib\/amavis\2/g' $dest/etc/amavis/amavisd.conf.new
sed -i 's/\(.*\)\/var\/amavis\(.*\)/\1\/var\/lib\/amavis\2/g' $dest/usr/sbin/amavisd-release
sed -i 's/\(.*\)\/var\/amavis\(.*\)/\1\/var\/lib\/amavis\2/g' $dest/usr/sbin/amavisd-nanny
sed -i 's/\(.*\)amavis\/amavisd\.lock\(.*\)/\1amavis\/home\/amavisd\.lock\2/g' \
    $dest/usr/sbin/amavisd-release
sed -i 's/\(.*\)amavis\/amavisd\.lock\(.*\)/\1amavis\/home\/amavisd\.lock\2/g' \
    $dest/usr/sbin/amavisd-nanny


# copy the doc files

cp -a \
    AAAREADME.first INSTALL LDAP.schema LICENSE MANIFEST README_FILES \
    RELEASE_NOTES TODO test-messages \
    amavisd-new* amavisd*.conf p0f-analyzer.pl \
    $dest/usr/doc/$softname-$softversion
echo " done"


#echo "re-ordering ..."
#( cd $dest
#    cp -a etc usr/doc/$softname-$softversion/
#    ( cd etc
#	mv mkcert.sh amavisd-new-mkcert.sh.new
#	mv amavisd-new-openssl.cnf amavisd-new-openssl.cnf.new
#	for file in * ; do
#	    newfile=`echo ${file} | sed "s/\-example\.conf/\.conf\.new/g"`
#	    echo "${file} -> ${newfile}"
#	    mv ${file} ${newfile}
#	done
#    )
#)


echo -n "creating rc script ..."
# put the initialization script in $dest/etc/rc.d/
mkdir -p $dest/etc/rc.d

echo "#!/bin/sh
#
# /etc/rc.d/rc.amavisd
# Start/stop/restart the Amavisd-New server.
#
# To make amavisd-new start automatically at boot, make this
# file executable: chmod 755 /etc/rc.d/rc.amavisd
#

case \"\$1\" in
   'start')
      amavisd -c /etc/amavis/amavisd.conf ;;
   'stop')
      killall amavisd;;
   'restart')
      killall amavisd
      amavisd -c /etc/amavis/amavisd.conf ;;
   *)
      echo \"usage \$0 start|stop|restart\" ;;
esac

" > $dest/etc/rc.d/rc.amavisd.new

chmod 644 $dest/etc/rc.d/rc.amavisd.new
chown root.root $dest/etc/rc.d/rc.amavisd.new

echo " done"

# strip executables
echo -n "stripping ..."
( cd $dest
   find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
   find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

echo " done"

##No man at all !!!
# gzip man pages and info files
#echo "gzipping ..."
#gzip -9 $dest/usr/man/*/*

# put the ZenWalk build and other needed files in the right directory
echo -n "setting perms ..."
cp -a $buildir/build-$softname.sh $dest/usr/src/$softname-$softversion
chown -R root.root $dest/usr/src/$softname-$softversion

# change files ownerships for $dest/usr/sbin
# NO $dest/usr/bin at all
#chown -R root.root $dest/usr/bin
chown -R root.root $dest/usr/sbin

# make the package and move it to the build directory

# create doinst.sh file
echo "config() {
  NEW=\"\$1.new\"
  OLD=\"\$1\"
  # If there's no config file by that name, mv it over:
  if [ ! -r \$OLD ]; then
    mv \$NEW \$OLD
  elif [ \"\`cat \$OLD | md5sum\`\" = \"\`cat \$NEW | md5sum\`\" ]; then
    # toss the redundant copy
    rm \$NEW
  fi
  # Otherwise, we leave the .new copy for netpkg to consider...
}

mychmod() {
  if [ -a \$2.new ]; then
    chmod \$1 \$2.new
  else
    chmod \$1 \$2
  fi
}

mychown() {
  if [ -a \$2.new ]; then
    chown \$1 \$2.new
  else
    chown \$1 \$2
  fi
}


mycreatedir() {
if [ ! -d \$1 ] ; then
        mkdir -p \$1
fi
}


# check if required user & groups exist &
# otherwise add them
if ! grep -q amavis /etc/group; then
        groupadd amavis
fi
if ! grep -q amavis /etc/passwd; then
        useradd -g amavis -d /var/lib/amavis -c 'Amavisd-New' -s /bin/false amavis
fi

if grep -q clamav /etc/group; then
        usermod -G clamav amavis
fi

if [ -a /etc/clamav/clamd.conf ] ; then
        sed -i 's/\(.*AllowSupplementaryGroups *\)no\(.*\)/\1yes\2/g' /etc/clamav/clamd.conf
fi

mycreatedir var/lib/amavis/home
mycreatedir var/lib/amavis/tmp
mycreatedir var/lib/amavis/var
mycreatedir var/lib/amavis/db
mycreatedir var/lib/amavis/quarantine

config etc/amavis/amavisd.conf
config etc/rc.d/rc.amavisd


mychown amavis:amavis var/lib/amavis/home
mychown amavis:amavis var/lib/amavis/tmp
mychown amavis:amavis var/lib/amavis/var
mychown amavis:amavis var/lib/amavis/db
mychown amavis:amavis var/lib/amavis/quarantine

mychmod 750 var/lib/amavis/home
mychmod 750 var/lib/amavis/tmp
mychmod 750 var/lib/amavis/var
mychmod 750 var/lib/amavis/db
mychmod 750 var/lib/amavis/quarantine

mychown root:amavis etc/amavis/amavisd.conf
mychmod 640 etc/amavis/amavisd.conf

chown -R amavis:amavis var/lib/amavis
chmod -R 750 var/lib/amavis

" > $dest/install/doinst.sh

chmod 755 $dest/install/doinst.sh

echo " done"


##------------------( Create The *.dep File )
echo -n "creating .dep ..."
#cd $dest
#requiredbuilder -z $dest > $buildir/$package.dep
echo -n "perl,perl-BerkeleyDB,perl-Compress-Zlib,perl-MIME-tools,perl-Net-Server,perl-Unix-Syslog" > $buildir/$package.dep

echo " done"

cd $dest
makepkg -l y -c n $package.tgz
mv $package.tgz $buildir

# computes the md5sum signature for the package
echo -n "creating .md5 ..."
cd $buildir
md5sum $package.tgz > $package.md5

if [ "$1" == "--cleanup" ]; then
  rm -rf $dest
  rm -rf $srcdir
fi

echo " done"
echo "ALL done :)"
